#
# spec file for package opentoonz
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __requires_exclude ^(libcolorfx|libimage|libsound|libtif).*
%global __provides_exclude ^(libcolorfx|libimage|libsound|libtif).*
Name:           opentoonz
Version:        1.1.2
Release:        lp150.1.10
Summary:        2D animation software
# need to review license as site indicates: "modified BSD license"
License:        BSD-2-Clause
Group:          Productivity/Graphics/Other
Url:            https://opentoonz.github.io/e/
Source0:        %{name}-v%{version}.tar.xz
Source1:        %{name}.desktop
Source2:        %{name}.png
Source3:        %{name}-rpmlintrc
Patch1:         p_handle-no-return-in-nonvoid-function.patch
Patch2:         p_add-zlo-to-cmake-include-path-suffixes.patch
Patch10:        https://github.com/opentoonz/opentoonz/commit/fb7729aaaf5c36f059c389b103126c2b039280b6.patch
Patch11:        https://github.com/opentoonz/opentoonz/commit/3ebaf33693caa2d9faf3cfad864f84c638e2cabe.patch
BuildRequires:  boost-devel >= 1.55
BuildRequires:  cmake
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5OpenGL-devel
BuildRequires:  libSDL2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng16-compat-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  libqt5-qtbase-devel >= 5.5
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtscript-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libusb-devel
BuildRequires:  lzo-devel
BuildRequires:  openblas-devel
BuildRequires:  pkgconfig
BuildRequires:  superlu-devel
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(liblz4)
# freetype2-devel
BuildRequires:  pkgconfig(freetype2)
# needed to setup startup script paths
BuildRequires:  sed
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  i586 x86_64

%description
2D animation software previously known as Toonz.

%prep
%setup -q -n %{name}-v%{version}
%patch1 -p1
%patch2 -p1
%patch10 -p1
%patch11 -p1

# Remove all thirdparty except tiff which is patched.
find thirdparty/* -maxdepth 0 ! -name "tiff-*" ! -name "lzo" -type d -exec rm -r "{}" \;
# Keep thirdparty/lzo/driver, but remove library.
rm -r thirdparty/lzo/2.*

%build
# TODO upstream planning to replace custom thirdparty libs with system versions
cd thirdparty/tiff-*
export CFLAGS="%optflags -fPIC"
%configure
%make_build
cd -

cd toonz
%define __sourcedir sources
%cmake \
  -DCMAKE_EXE_LINKER_FLAGS="-Wl,--no-as-needed" \
  -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--no-as-needed" \
  -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--no-as-needed"

%make_jobs

%install
cd toonz
%cmake_install

# fix lib dir since install puts 64bit libs in /usr/lib/
%ifarch x86_64
mkdir -p %{buildroot}%{_libdir}/%{name}
mv %{buildroot}/usr/lib/%{name}/* %{buildroot}%{_libdir}/%{name}
rm -r %{buildroot}/usr/lib/%{name}

# fix launch script that references lib/ instead of lib64/.
sed -i 's|/lib/|/lib64/|' %{buildroot}%{_bindir}/%{name}
%endif

# install desktop file and icon
install -D -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}.desktop

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_bindir}/OpenToonz_*
%{_bindir}/tcleanup
%{_bindir}/tcomposer
%{_bindir}/tconverter
%{_bindir}/tfarmcontroller
%{_bindir}/tfarmserver
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_libdir}/%{name}

%changelog
* Fri Jul 28 2017 olaf@aepfle.de
- Use pkgconfig(liblz4)
* Wed Feb  1 2017 jimmy@boombatower.com
- Utilize ExclusiveArch to avoid architectures that fail to build.
* Thu Jan 26 2017 jimmy@boombatower.com
- Drop thirdparty/* (except patched tiff and lzo/driver) to ensure
  built against system libraries.
- Backport upstream commits for superlu 5.x compatibility.
  * 3ebaf33693caa2d9faf3cfad864f84c638e2cabe.patch
  * fb7729aaaf5c36f059c389b103126c2b039280b6.patch
- Include lzo suffix in path:
  p_add-zlo-to-cmake-include-path-suffixes.patch
* Sat Nov 26 2016 jimmy@boombatower.com
- Update to version 1.1.2:
  * organize palette 1
  * updated style link and right click menu
  * Changed connection to reference
  * organize palette 2
  * bring panel title bar to the style sheet
  * support for jpeg import (#656)
  * Add format string literal
  * Cleanup: format warnings
  * introducing stage-standarddpi
  * Added UHD and reordered reslist, added DCI 2K and 4K to cleanupreslist (#672)
  * Fixed assert failing on project popup (#646)
  * add dpi compatibility check and remove comment
  * Allow Enter in Save File Field to Save (#687)
  * Disable onionskin during playback (#708)
  * organize palette 3
  * Level Settings Popup: removed name unchanged warning and set focus on other errors (#686)
  * Add source formatting check (#689)
  * Fix for clang-format (#743)
  * resize scene instead of changing dpi
  * fix beautification script (#745)
  * Improvement of direct inputting feature in Xsheet (#722)
  * Add Hidden Commands to Menus (#677)
  * New Geometry Icon (#716)
  * Corrected some spelling mistakes
  * organize_palette 4
  * Typo fixes (#531)
  * sceneviewer fix for updating markers (#778)
  * camera capture fixes
  * remove onion cursor on mouse leave
  * fix mesh preview blackout on opening popup
  * add style sheet for sound column
  * :bug: Fix spelling mistakes
  * Translate comments to English
  * Mp3 Import (#749)
  * clang format (#797)
  * modify tif_config for msvc (#796)
  * Replace else() with elseif(APPLE) to ensure quicktime not built on unix.
  * Update openSUSE build requirements.
  * numpad for palette shortcut
  * fix version numbers
  * revert autocenter in cleanup settings
  * Fix save all issue setting wrong path on cancel save scene (#775)
  * enable shift + tab
  * status -> state
  * Additional Project Root Location (#664)
  * revert link style
  * small fixes
  * fix libpng for msvc2015_x86 (#831)
  * libtiff/Makefile.am: add tif_getimage_64.c
  * Save settings updated - Updated and Fixed (#474)
  * add video capture filter settings
  * fix gif reader not getting all frames (#770)
  * remove find_library and small fix
  * Fix/Workaround bug #591
  * set dirty flag on clone levels
  * Docs: Add links to Linux package definitions
  * Update required packages list on Fedora
  * add remove unused styles option
  * Fix for ffmpeg named with sequence names (#826)
  * Fix for Multiple FFmpeg files with same name #813 (#827)
  * Show info for ffmpeg levels (#824)
  * fix for ffmpeg export range error (#828)
  * Shortcuts Selection Choice and Proposed New Shortcuts (#691)
  * locator popup
  * fix load scene for relative project folder
  * Startup popup when OT starts (#793)
  * highlight recent items on mouse hover
  * fixes
  * Unify all scrollbars to same style
  * save format properties
  * fix studiopalette drag
  * rounded brush cap default (#872)
  * Fix for crash inserting a keyframe (#798)
  * Fix for FFmpeg renders wrong range if previous exported range was bigger  (#814)
  * CMake: minor cleanup
  * buttons on viewer and combo unified (#873)
  * fix not to browse initial description text
  * Update required package list for Debian / Ubuntu
  * enable shortcut in paletteviewer
  * Sound playback in the viewer (#788)
  * small fixes and change default shortcuts
  * Minor edits
  * Linux Readme: remove Unix from title.
  * Simplify libtiff building
  * Correct typo
  * Add note about jbig error
  * enable numpad
  * Update Linux install text
  * Update how_to_build_linux.md
  * changed scrollbar width to 16
  * change margin for button to 16
  * Quick Export Feature (#725)
  * fix convert to painted tlv
  * easy input for name editor
  * medium chip menu
  * CMake: ensure Qt isn't too old
  * Comments: translate icon-generator notes
  * dialog position fix
  * fixes
  * resizable buttons
  * label on top
  * Fixes crash on editing curve with control point tool
  * display sound level settings and info
  * moved ffmpeg temp files to cache folder (#921)
  * modify next / prev drawing
  * Audio Recording Popup (#786)
  * Add a load image button to camera capture for reference image (#751)
  * Spritesheet Export (#752)
  * Fix use after free error (#896)
  * Fixed gif import (#924)
  * fix style switch on raster
  * Update .ts files and Japanese translations (#842)
  * v1.1.2 (#935)
- Remove upstreamed p_ensure-quicktime-not-built.patch.
* Fri Sep 23 2016 jimmy@boombatower.com
- Utilize updated cmake macro with customizable sourcedir.
  https://build.opensuse.org/request/show/426207
  Correction after it was changed:
  https://build.opensuse.org/request/show/430013
* Sat Sep 10 2016 jimmy@boombatower.com
- Reference opentoonz-rpmlintrc as source.
* Sat Sep 10 2016 jimmy@boombatower.com
- Change source from ideasman42/opentoonz to opentoonz/opentoonz.
- Replace libpng build with libpng16-compat-devel after upstream resolution.
- Update SDL dependency to 2.x.
- Add libqt5-qtmultimedia-devel, libQt5OpenGL-devel, and libquicktime-devel as
  build requirements.
- Replace custom install process with upstreamed process.
- Build custom bundled libtiff with standard flags.
- Add patch for compile issues:
    p_ensure-quicktime-not-built.patch
    p_handle-no-return-in-nonvoid-function.patch
* Fri Sep  9 2016 jimmy@boombatower.com
- Update to version v1.1.1+git20160808:
  * Fixed preset dropdown, dpi lock, labels, decimals
  * FFmpeg Integration - mp4, webm, gif (#624)
  * Updated rooms for consistency (#584)
  * change to move thread before destructor called (#702)
  * clang formatting (#703)
  * v1.1.0 (#704)
  * clang format
  * fix for 1.1.0 (#711)
  * update systemvar to 1.1
  * v1.1.1 (#718)
* Sat Apr  9 2016 jimmy@boombatower.com
- Finalize installation (in lieu of upstream make install).
- Resolved many build time issues.
- Add rpmlintrc file.
- Add opentoonz.sh to automate first run.
* Thu Mar 31 2016 jimmy@boombatower.com
- Initial v1.0 packaging from ideasman42/opentoonz:linux_fix_wip.
